<?php
/**
 * @package     Joomla.Plugin
 * @subpackage  User.profile
 *
 * @copyright   Copyright (C) 2005 - 2012 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('JPATH_PLATFORM') or die;

JFormHelper::loadFieldClass('radio');

/**
 * Provides selection for starting avatar in OpenSim
 *
 * @package     Joomla.Plugin
 * @subpackage  User.profile
 * @since       2.5.5
 */
class JFormFieldAvatar extends JFormFieldRadio {
	/**
	 * The form field type.
	 *
	 * @var    string
	 * @since  2.5.5
	 */
	protected $type = 'Avatar';

	/**
	 * Method to get the field label markup.
	 *
	 * @return  string  The field label markup.
	 *
	 * @since   2.5.5
	 */
	protected function getLabel() {
		// Initialise variables.
		$label = '';

		if ($this->hidden) {
			return $label;
		}

		$plgRegisterjOpenSim =& JPluginHelper::getPlugin('user', 'jopensimregister');
		$this->params   	= new JParameter($plgRegisterjOpenSim->params);
		$avatarlist = $this->params->get('plgJopensimRegisterAvatar');
//		$label .= "(".var_export($avatarlist,TRUE).") ";

		// Get the label text from the XML element, defaulting to the element name.
		$text = $this->element['label'] ? (string) $this->element['label'] : (string) $this->element['name'];
		$text = $this->translateLabel ? JText::_($text) : $text;

		// Set required to true as this field is not displayed at all if not required.
		$this->required = true;

		// Add CSS and JS for the TOS field
		$doc = JFactory::getDocument();
		$css = "#jform_jopensimregister_jopensimavatar {margin: 0 !important; padding: 0px 2px 5px 2px !important;}
				#jform_jopensimregister_jopensimavatar input {margin:5px 15px 0px 5px !important; width:10px !important;}";
		$doc->addStyleDeclaration($css);

		JHtml::_('behavior.modal');

		// Build the class for the label.
		$class = !empty($this->description) ? 'hasTip' : '';
		$class =$class . ' required';
		$class = !empty($this->labelClass) ? $class . ' jopensimavatar ' . $this->labelClass : $class.' jopensimavatar';

		// Add the opening label tag and main attributes attributes.
		$label .= '<label id="' . $this->id . '-lbl" for="' . $this->id . '" class="' . $class . '"';

		// If a description is specified, use it to build a tooltip.
		if (!empty($this->description)) {
			$label .= ' title="'
				. htmlspecialchars(
				trim($text, ':') . '::' . ($this->translateDescription ? JText::_($this->description) : $this->description),
				ENT_COMPAT, 'UTF-8'
			) . '"';
		}
		
		$avatararticle = $this->element['article'] ? (int) $this->element['article'] : 1;
		$link = '<a class="modal" title="" href="index.php?option=com_content&amp;view=article&amp;layout=modal&amp;id=' . $avatararticle . '&amp;tmpl=component" rel="{handler: \'iframe\', size: {x:800, y:500}}">' . $text . '</a>';

		// Add the label text and closing tag.
		$label .= '>' . $link . '</label>';
//		$label .= "<pre>\n".var_export($this->element,TRUE)."</pre>\n";

		return $label;
	}


	protected function getOptions() {
		// Initialize variables.
		$options = array();
		$avatars = array();
		
		$plgRegisterjOpenSim =& JPluginHelper::getPlugin('user', 'jopensimregister');
		$this->params   	= new JParameter($plgRegisterjOpenSim->params);
		$avatarlist = $this->params->get('plgJopensimRegisterAvatar');
		if(is_array($avatarlist) && count($avatarlist) > 0) {
			foreach($avatarlist AS $avatar) {
				$zaehler = count($avatars);
				$temp = explode(":",$avatar);
				$avatars[$zaehler]['value'] = $temp[0];
				if(is_file(JPATH_SITE.DS.'images'.DS.'jopensim'.DS.'avatars'.DS.$temp[0].'.jpg')) {
					$attr['title'] = $temp[1];
					$attr['align'] = "absmiddle";
					$img = JHtml::image("images/jopensim/avatars/".$temp[0].".jpg",$temp[1],$attr);
					$avatars[$zaehler]['text'] = $img;
					$avatars[$zaehler]['class'] = "required jopensimavatar";
					$avatars[$zaehler]['required'] = TRUE;
				} elseif(is_file(JPATH_SITE.DS.'images'.DS.'jopensim'.DS.'avatars'.DS.$temp[0].'.png')) {
					$attr['title'] = $temp[1];
					$attr['align'] = "absmiddle";
					$img = JHtml::image("images/jopensim/avatars/".$temp[0].".png",$temp[1],$attr);
					$avatars[$zaehler]['text'] = $img;
					$avatars[$zaehler]['class'] = "required jopensimavatar";
					$avatars[$zaehler]['required'] = TRUE;
				} else {
					$avatars[$zaehler]['text'] = $temp[1];
				}
			}
		} else {
			$avatars[0]['value'] = "-1";
			$avatars[0]['text'] = JText::_('PLG_JOPENSIMREGISTER_ERROR_NOAVATARS');
		}

/*
		$test[0]['value'] = "0";
		$test[0]['text'] = "test0";
		$test[1]['value'] = "1";
		$test[1]['text'] = "test1";
		$test[2]['value'] = "2";
		$test[2]['text'] = "test2";
*/

		foreach ($avatars as $option) {

			// Create a new option object based on the <option /> element.
			$tmp = JHtml::_(
				'select.option', (string) $option['value'], trim((string) $option['text']), 'value', 'text'
			);

			// Set some option attributes.
			if(array_key_exists("class",$option)) $tmp->class = (string) $option['class'];

			// Set some JavaScript option attributes.
			if(array_key_exists("onclick",$option)) $tmp->onclick = (string) $option['onclick'];

			/*$tmp = JHtml::_(div,$tmp);*/

			// Add the option object to the result set.
			$options[] = $tmp;
		}

		reset($options);

		return $options;
	}
}
